summaryrefslogtreecommitdiff
path: root/src/script/api/script_grouplist.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/script/api/script_grouplist.hpp')
-rw-r--r--src/script/api/script_grouplist.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/script/api/script_grouplist.hpp b/src/script/api/script_grouplist.hpp
index 3e02d1ce3..6ce66c16c 100644
--- a/src/script/api/script_grouplist.hpp
+++ b/src/script/api/script_grouplist.hpp
@@ -16,12 +16,12 @@
/**
* Creates a list of groups of which you are the owner.
* @note Neither AIGroup::GROUP_ALL nor AIGroup::GROUP_DEFAULT is in this list.
* @ingroup AIList
*/
-class AIGroupList : public AIList {
+class ScriptGroupList : public ScriptList {
public:
- AIGroupList();
+ ScriptGroupList();
};
#endif /* SCRIPT_GROUPLIST_HPP */
@@ -16,12 +16,12 @@
/**
* Creates a list of groups of which you are the owner.
- * @note Neither AIGroup::GROUP_ALL nor AIGroup::GROUP_DEFAULT is in this list.
- * @ingroup AIList
+ * @note Neither ScriptGroup::GROUP_ALL nor ScriptGroup::GROUP_DEFAULT is in this list.
+ * @ingroup ScriptList
*/